@@ -1,6 +1,6 @@
 package ZMQ::FFI;
 {
-  $ZMQ::FFI::VERSION = '0.12';
+  $ZMQ::FFI::VERSION = '0.13';
 }
 # ABSTRACT: zeromq bindings using libffi and FFI::Raw
 
@@ -44,7 +44,7 @@ ZMQ::FFI - zeromq bindings using libffi and FFI::Raw
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
@@ -232,7 +232,7 @@ zeromq thread pool size. Default: 1
 
 =item max_sockets
 
-I<only for zeromq 3.x>
+I<requires zmq E<gt>= 3.x>
 
 max number of sockets allowed for context. Default: 1024
 
@@ -254,7 +254,7 @@ return the libzmq version as the list C<($major, $minor, $patch)>
 
 =head2 get($option)
 
-I<only for zeromq 3.x>
+I<requires zmq E<gt>= 3.x>
 
     $ctx->get(ZMQ_IO_THREADS)
 
@@ -262,7 +262,7 @@ get a context option value
 
 =head2 set($option, $option_value)
 
-I<only for zeromq 3.x>
+I<requires zmq E<gt>= 3.x>
 
     $ctx->set(ZMQ_MAX_SOCKETS, 42)
 
@@ -302,6 +302,12 @@ does socket connect on the specified endpoint
 
 does socket bind on the specified endpoint
 
+=head2 unbind($endpoint)
+
+I<requires zmq E<gt>= 3.x>
+
+does socket unbind on the specified endpoint
+
 =head2 get_linger(), set_linger($millis)
 
 get or set the current socket linger period
