@@ -1,6 +1,6 @@
 package ZMQ::FFI::SocketBase;
 {
-  $ZMQ::FFI::SocketBase::VERSION = '0.12';
+  $ZMQ::FFI::SocketBase::VERSION = '0.13';
 }
 
 use Moo;
@@ -78,6 +78,10 @@ sub connect {
     );
 }
 
+sub disconnect {
+    croak 'unimplemented in base class';
+}
+
 sub bind {
     my ($self, $endpoint) = @_;
 
@@ -91,6 +95,10 @@ sub bind {
     );
 }
 
+sub unbind {
+    croak 'unimplemented in base class';
+}
+
 sub send {
     croak 'unimplemented in base class';
 }
@@ -453,7 +461,7 @@ ZMQ::FFI::SocketBase
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 AUTHOR
 
