@@ -1,11 +1,12 @@
 package ZMQ::FFI::ZMQ3::Socket;
 {
-  $ZMQ::FFI::ZMQ3::Socket::VERSION = '0.12';
+  $ZMQ::FFI::ZMQ3::Socket::VERSION = '0.13';
 }
 
 use Moo;
 use namespace::autoclean;
 
+use Carp;
 use FFI::Raw;
 
 extends q(ZMQ::FFI::SocketBase);
@@ -71,6 +72,32 @@ sub recv {
     return $rv;
 }
 
+sub disconnect {
+    my ($self, $endpoint) = @_;
+
+    unless ($endpoint) {
+        croak 'usage: $socket->disconnect($endpoint)';
+    }
+
+    $self->check_error(
+        'zmq_disconnect',
+        $self->_zmq3_ffi->{zmq_disconnect}->($self->_socket, $endpoint)
+    );
+}
+
+sub unbind {
+    my ($self, $endpoint) = @_;
+
+    unless ($endpoint) {
+        croak 'usage: $socket->unbind($endpoint)';
+    }
+
+    $self->check_error(
+        'zmq_unbind',
+        $self->_zmq3_ffi->{zmq_unbind}->($self->_socket, $endpoint)
+    );
+}
+
 sub _init_zmq3_ffi {
     my $self = shift;
 
@@ -94,6 +121,20 @@ sub _init_zmq3_ffi {
         FFI::Raw::int  # flags
     );
 
+    $ffi->{zmq_unbind} = FFI::Raw->new(
+        $soname => 'zmq_unbind',
+        FFI::Raw::int,
+        FFI::Raw::ptr,
+        FFI::Raw::str
+    );
+
+    $ffi->{zmq_disconnect} = FFI::Raw->new(
+        $soname => 'zmq_disconnect',
+        FFI::Raw::int,
+        FFI::Raw::ptr,
+        FFI::Raw::str
+    );
+
     return $ffi;
 }
 
@@ -109,7 +150,7 @@ ZMQ::FFI::ZMQ3::Socket
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 AUTHOR
 
